###############
 Preprocessing
###############

The preprocessing module is used to pre- and post-process the data. The
module contains the following classes:

.. automodule:: anemoi.models.preprocessing
   :members:
   :no-undoc-members:
   :show-inheritance:

************
 Normalizer
************

The normalizer module is used to normalize the data. The module contains
the following classes:

.. automodule:: anemoi.models.preprocessing.normalizer
   :members:
   :no-undoc-members:
   :show-inheritance:

*********
 Imputer
*********

The imputer module is used to impute the data. The module contains the
following classes:

.. automodule:: anemoi.models.preprocessing.imputer
   :members:
   :no-undoc-members:
   :show-inheritance:

**********
 Remapper
**********

The remapper module is used to remap one variable to multiple other
variables that have been listed in data.remapped:. The module contains
the following classes:

.. automodule:: anemoi.models.preprocessing.remapper
   :members:
   :no-undoc-members:
   :show-inheritance:
